@@ -14,15 +14,5 @@ RSpec.configure do |config|
   end
 end
 
-def gcm_supported?
-  ['aes-128-gcm', 'aes-128-gcm'].all? do |alg|
-    OpenSSL::Cipher.ciphers.include? alg
-  end
-end
-
-def pss_supported?
-  OpenSSL::VERSION >= '2.1.0'
-end
-
 require 'helpers/sign_key_fixture_helper'
 require 'helpers/nimbus_spec_helper'
